@@ -2,7 +2,7 @@ package Geo::Gpx::Point;
 use strict;
 use warnings;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 =encoding utf8
 
@@ -23,7 +23,6 @@ L<Geo::Gpx::Point> provides a data structure for GPX points and provides accesso
 use DateTime::Format::ISO8601;
 use Geo::Calc;
 use Geo::Coordinates::Transform;
-use Scalar::Util qw( blessed );
 use Carp qw(confess croak cluck);
 use vars qw($AUTOLOAD %possible_attr);
 use overload ('""' => 'as_string');
@@ -66,11 +65,9 @@ sub new {
         } else { croak "field '$key' not supported" }
     }
 
-    if (defined $wpt->{time} and ! blessed $wpt->{time}) {  # i.e could already be a DateTime object
-        if ($wpt->{time} =~ /-|:/) {
-            my $dt = DateTime::Format::ISO8601->parse_datetime( $wpt->{time} );
-            $wpt->{time} = $dt->epoch
-        }
+    if (defined $wpt->{time} and $wpt->{time} =~ /-|:/ ) {
+        my $dt = DateTime::Format::ISO8601->parse_datetime( $wpt->{time} );
+        $wpt->{time} = $dt->epoch
     }
     return $wpt
 }
@@ -212,6 +209,26 @@ sub to_tcx {
 
 =over 4
 
+=item time_datetime ()
+
+Return a L<DateTime> object corresponding to the time of the point. The C<time_zone> of the object will be C<< 'UTC' >>. Specify C<< time_zone => $tz >> to set a different one.
+
+=back
+
+=cut
+
+# we never store a DateTime object but provide a method to return one
+sub time_datetime    {
+    my $pt = shift;
+    my %opts = @_;
+    croak 'Geo::Gpx::Point has no time field' unless $pt->time;
+    my $dt = DateTime->from_epoch( $pt->time );
+    $dt->set_time_zone( $opts{time_zone} ) if $opts{time_zone};
+    return  $dt
+}
+
+=over 4
+
 =item summ()
 
 For debugging purposes mostly. Summarizes the fields of point by printing to screen. Returns nothing.
@@ -263,7 +280,7 @@ Patrick Joly C<< <patjol@cpan.org> >>.
 
 =head1 VERSION
 
-1.05
+1.06
 
 =head1 SEE ALSO
 
